<?php
namespace Deposits_WooCommerce\Emails;

/**
 * Class DepositOrder file.
 */

if ( !class_exists( 'DepositOrder' ) ):

    /**
     * Customer Deposit Invoice.
     *
     * An email sent to the customer .
     *
     * @class       WC_Email_Customer_Deposit
     * @version     1.3
     * @package     Deposits_WooCommerce
     * @extends     WC_Email
     */
    class DepositOrder extends \WC_Email {

        /**
         * Constructor.
         */
        public function __construct() {
            $this->id             = 'customer_deposit';
            $this->customer_email = true;
            $this->title          = __( 'Deposit order', 'deposits-for-woocommerce' );
            $this->description    = __( 'Customer deposit emails can be sent to customers containing their deposit information and payment links.', 'deposits-for-woocommerce' );
            $this->template_html  = 'emails/customer-deposit.php';
            $this->template_plain = 'emails/plain/customer-deposit.php';
            $this->placeholders   = array(
                '{order_date}'   => '',
                '{order_number}' => '',
            );

            // Call parent constructor.
            parent::__construct();
            $this->template_base = CIDW_TEMPLATE_PATH;
            //  $this->manual = true;
        }

        /**
         * Get email subject.
         *
         * @param bool $paid Whether the order has been paid or not.
         * @since  1.3
         * @return string
         */
        public function get_default_subject() {
            return __( '{site_title} : Deposit for order #{order_number}', 'deposits-for-woocommerce' );
        }

        /**
         * Get email heading.
         *
         * @param bool $paid Whether the order has been paid or not.
         * @since  1.3
         * @return string
         */
        public function get_default_heading() {
            return __( '{site_title} : Deposit order #{order_number}', 'deposits-for-woocommerce' );
        }

        /**
         * Default content to show below main email content.
         *
         * @since 3.7.0
         * @return string
         */
        public function get_default_additional_content() {
            return __( 'Thanks for using {site_url}!', 'deposits-for-woocommerce' );
        }

        /**
         * Get email subject.
         *
         * @return string
         */
        public function get_subject() {
            $subject = $this->get_option( 'subject', $this->get_default_subject() );
            return apply_filters( 'woocommerce_email_subject_customer_invoice', $this->format_string( $subject ), $this->object, $this );
        }
        /**
         * Get email heading.
         *
         * @return string
         */
        public function get_heading() {
            $heading = $this->get_option( 'heading', $this->get_default_heading() );
            return apply_filters( 'woocommerce_email_heading_customer_invoice', $this->format_string( $heading ), $this->object, $this );
        }
        /**
         * Trigger the sending of this email.
         *
         * @param int      $order_id The order ID.
         * @param WC_Order $order Order object.
         */
        public function trigger( $order_id, $order = false ) {
            $this->setup_locale();

            if ( $order_id && !is_a( $order, 'WC_Order' ) ) {
                $order = wc_get_order( $order_id );
            }

            if ( is_a( $order, 'WC_Order' ) ) {
                $this->object                         = $order;
                $this->recipient                      = $this->object->get_billing_email();
                $this->placeholders['{order_date}']   = wc_format_datetime( $this->object->get_date_created() );
                $this->placeholders['{order_number}'] = $this->object->get_order_number();
            }

            if ( $this->is_enabled() && $this->get_recipient() ) {
                $this->send( $this->get_recipient(), $this->get_subject(), $this->get_content(), $this->get_headers(), $this->get_attachments() );
            }

            $this->restore_locale();
        }

        /**
         * Get content html.
         *
         * @return string
         */
        public function get_content_html() {
            return wc_get_template_html(
                $this->template_html,
                array(
                    'order'              => $this->object,
                    'email_heading'      => $this->get_heading(),
                    'additional_content' => $this->get_additional_content(),
                    'sent_to_admin'      => false,
                    'plain_text'         => false,
                    'email'              => $this,
                ),
                '',
                $this->template_base
            );
        }

        /**
         * Get content plain.
         *
         * @return string
         */
        public function get_content_plain() {
            return wc_get_template_html(
                $this->template_plain,
                array(
                    'order'              => $this->object,
                    'email_heading'      => $this->get_heading(),
                    'additional_content' => $this->get_additional_content(),
                    'sent_to_admin'      => false,
                    'plain_text'         => true,
                    'email'              => $this,
                ),
                '',
                $this->template_base
            );
        }

        /**
         * Initialise settings form fields.
         */
        public function init_form_fields() {
            /* translators: %s: list of placeholders */
            $placeholder_text  = sprintf( __( 'Available placeholders: %s', 'deposits-for-woocommerce' ), '<code>' . esc_html( implode( '</code>, <code>', array_keys( $this->placeholders ) ) ) . '</code>' );
            $this->form_fields = array(
                'enabled'            => array(
                    'title'   => __( 'Enable/Disable', 'deposits-for-woocommerce' ),
                    'type'    => 'checkbox',
                    'label'   => __( 'Enable this email notification', 'deposits-for-woocommerce' ),
                    'default' => 'yes',
                ),
                'subject'            => array(
                    'title'       => __( 'Subject', 'deposits-for-woocommerce' ),
                    'type'        => 'text',
                    'desc_tip'    => true,
                    'description' => $placeholder_text,
                    'placeholder' => $this->get_default_subject(),
                    'default'     => '',
                ),
                'heading'            => array(
                    'title'       => __( 'Email heading', 'deposits-for-woocommerce' ),
                    'type'        => 'text',
                    'desc_tip'    => true,
                    'description' => $placeholder_text,
                    'placeholder' => $this->get_default_heading(),
                    'default'     => '',
                ),

                'additional_content' => array(
                    'title'       => __( 'Additional content', 'deposits-for-woocommerce' ),
                    'description' => __( 'Text to appear below the main email content.', 'deposits-for-woocommerce' ) . ' ' . $placeholder_text,
                    'css'         => 'width:400px; height: 75px;',
                    'placeholder' => __( 'N/A', 'deposits-for-woocommerce' ),
                    'type'        => 'textarea',
                    'default'     => $this->get_default_additional_content(),
                    'desc_tip'    => true,
                ),
                'email_type'         => array(
                    'title'       => __( 'Email type', 'deposits-for-woocommerce' ),
                    'type'        => 'select',
                    'description' => __( 'Choose which format of email to send.', 'deposits-for-woocommerce' ),
                    'default'     => 'html',
                    'class'       => 'email_type wc-enhanced-select',
                    'options'     => $this->get_email_type_options(),
                    'desc_tip'    => true,
                ),
            );
        }
    }

endif;
